@@ -46,9 +46,6 @@ class GIRParser(object):
 
     def __init__(self, types_only=False):
         self._types_only = types_only
-        self._shared_libraries = []
-        self._includes = set()
-        self._pkgconfig_packages = set()
         self._namespace = None
         self._filename_stack = []
 
@@ -62,10 +59,9 @@ class GIRParser(object):
         self._filename_stack.pop()
 
     def parse_tree(self, tree):
-        self._includes.clear()
         self._namespace = None
-        self._shared_libraries = []
         self._pkgconfig_packages = set()
+        self._includes = set()
         self._c_includes = set()
         self._c_prefix = None
         self._parse_api(tree.getroot())
@@ -73,23 +69,9 @@ class GIRParser(object):
     def get_namespace(self):
         return self._namespace
 
-    def get_shared_libraries(self):
-        return self._shared_libraries
-
-    def get_includes(self):
-        return self._includes
-
-    def get_c_includes(self):
-        return self._c_includes
-
     def get_c_prefix(self):
         return self._c_prefix
 
-    def get_pkgconfig_packages(self):
-        if not hasattr(self, '_pkgconfig_packages'):
-            self._pkgconfig_packages = []
-        return self._pkgconfig_packages
-
     # Private
 
     def _find_first_child(self, node, name_or_names):
@@ -119,9 +101,8 @@ class GIRParser(object):
         assert root.tag == _corens('repository')
         version = root.attrib['version']
         if version != COMPATIBLE_GIR_VERSION:
-            raise SystemExit("%s: Incompatible version %s (supported: %s)" \
-                             % (self._get_current_file(),
-                                version, COMPATIBLE_GIR_VERSION))
+            raise SystemExit("%s: Incompatible version %s (supported: %s)" %
+                             (self._get_current_file(), version, COMPATIBLE_GIR_VERSION))
 
         for node in root.getchildren():
             if node.tag == _corens('include'):
@@ -140,12 +121,14 @@ class GIRParser(object):
         if symbol_prefixes:
             symbol_prefixes = symbol_prefixes.split(',')
         self._namespace = ast.Namespace(ns.attrib['name'],
-                                    ns.attrib['version'],
-                                    identifier_prefixes=identifier_prefixes,
-                                    symbol_prefixes=symbol_prefixes)
+                                        ns.attrib['version'],
+                                        identifier_prefixes=identifier_prefixes,
+                                        symbol_prefixes=symbol_prefixes)
         if 'shared-library' in ns.attrib:
-            self._shared_libraries.extend(
-                ns.attrib['shared-library'].split(','))
+            self._namespace.shared_libraries = ns.attrib['shared-library'].split(',')
+        self._namespace.includes = self._includes
+        self._namespace.c_includes = self._c_includes
+        self._namespace.exported_packages = self._pkgconfig_packages
 
         parser_methods = {
             _corens('alias'): self._parse_alias,
@@ -156,8 +139,7 @@ class GIRParser(object):
             _corens('interface'): self._parse_object_interface,
             _corens('record'): self._parse_record,
             _corens('union'): self._parse_union,
-            _glibns('boxed'): self._parse_boxed,
-            }
+            _glibns('boxed'): self._parse_boxed}
 
         if not self._types_only:
             parser_methods[_corens('constant')] = self._parse_constant
@@ -169,8 +151,7 @@ class GIRParser(object):
                 method(node)
 
     def _parse_include(self, node):
-        include = ast.Include(node.attrib['name'],
-                          node.attrib['version'])
+        include = ast.Include(node.attrib['name'], node.attrib['version'])
         self._includes.add(include)
 
     def _parse_pkgconfig_package(self, node):
@@ -181,9 +162,7 @@ class GIRParser(object):
 
     def _parse_alias(self, node):
         typeval = self._parse_type(node)
-        alias = ast.Alias(node.attrib['name'],
-                      typeval,
-                      node.attrib.get(_cns('type')))
+        alias = ast.Alias(node.attrib['name'], typeval, node.attrib.get(_cns('type')))
         self._parse_generic_attribs(node, alias)
         self._namespace.append(alias)
 
@@ -443,7 +422,8 @@ class GIRParser(object):
                 return ast.Type(ctype=ctype)
             elif name in ['GLib.List', 'GLib.SList']:
                 subchild = self._find_first_child(typenode,
-                               map(_corens, ('callback', 'array', 'varargs', 'type')))
+                                                  map(_corens, ('callback', 'array',
+                                                                'varargs', 'type')))
                 if subchild is not None:
                     element_type = self._parse_type(typenode)
                 else:
@@ -454,9 +434,7 @@ class GIRParser(object):
                 subchildren_types = map(self._parse_type_simple, subchildren)
                 while len(subchildren_types) < 2:
                     subchildren_types.append(ast.TYPE_ANY)
-                return ast.Map(subchildren_types[0],
-                           subchildren_types[1],
-                           ctype=ctype)
+                return ast.Map(subchildren_types[0], subchildren_types[1], ctype=ctype)
             else:
                 return self._namespace.type_from_name(name, ctype)
         else:
@@ -478,8 +456,8 @@ class GIRParser(object):
         lenidx = typenode.attrib.get('length')
         if lenidx is not None:
             idx = int(lenidx)
-            assert idx < len(parent.parameters), "%r %d >= %d" \
-                      % (parent, idx, len(parent.parameters))
+            assert idx < len(parent.parameters), "%r %d >= %d" % (parent, idx,
+                                                                  len(parent.parameters))
             typeval.length_param_name = parent.parameters[idx].argname
 
     def _parse_boxed(self, node):
@@ -525,11 +503,11 @@ class GIRParser(object):
             assert node.tag == _corens('field'), node.tag
             type_node = self._parse_type(node)
         field = ast.Field(node.attrib.get('name'),
-                      type_node,
-                      node.attrib.get('readable') != '0',
-                      node.attrib.get('writable') == '1',
-                      node.attrib.get('bits'),
-                      anonymous_node=anonymous_node)
+                          type_node,
+                          node.attrib.get('readable') != '0',
+                          node.attrib.get('writable') == '1',
+                          node.attrib.get('bits'),
+                          anonymous_node=anonymous_node)
         field.private = node.attrib.get('private') == '1'
         field.parent = parent
         self._parse_generic_attribs(node, field)
@@ -537,12 +515,12 @@ class GIRParser(object):
 
     def _parse_property(self, node, parent):
         prop = ast.Property(node.attrib['name'],
-                        self._parse_type(node),
-                        node.attrib.get('readable') != '0',
-                        node.attrib.get('writable') == '1',
-                        node.attrib.get('construct') == '1',
-                        node.attrib.get('construct-only') == '1',
-                        node.attrib.get('transfer-ownership'))
+                            self._parse_type(node),
+                            node.attrib.get('readable') != '0',
+                            node.attrib.get('writable') == '1',
+                            node.attrib.get('construct') == '1',
+                            node.attrib.get('construct-only') == '1',
+                            node.attrib.get('transfer-ownership'))
         self._parse_generic_attribs(node, prop)
         prop.parent = parent
         return prop
