@@ -4007,3 +4007,11 @@ void
 regress_test_versioning (void)
 {
 }
+
+void
+regress_like_xkl_config_item_set_name (RegressLikeXklConfigItem *self,
+                                       const char *name)
+{
+  strncpy (self->name, name, sizeof (self->name) - 1);
+  self->name[sizeof(self->name)-1] = '\0';
+}
